.xprez-clipboard-copy {
	.xprez-inline-success-message {
		display: none;
	}

	&.success {
		.xprez-inline-success-message {
			display: flex;
		}

		.default {
			display: none;
		}
	}

	.check {
		color: green;
	}
}

.xprez-inline-success-message {
	display: flex;
	align-items: center;

	svg {
		width: 24px;
		height: 24px;
		margin: -4px 0;
	}
}

.xprez-clipboard-list {
	border: 1px solid $b-gray-6;
	border-radius: 2px;
	background: lighten($b-gray-3, 2%);
	font-size: .875rem;
	overflow-y: auto;
	max-height: 300px;
	max-width: 600px;
	margin: 2rem auto;

	&__item {
		padding: .5rem 8px;
		display: flex;
		align-items: center;
		gap: .5rem;
		transition: background linear .3s;

		&:not(:last-child) {
			border-bottom: 1px solid $b-gray-5;
		}

		&:hover {
			background: lighten($b-gray-3, 6%);
		}
	}

	&__info {
		flex: 1;

		i {
			opacity: .7;
		}
	}

	&__module {
		font-weight: 600;
	}

	&__icon {
		align-self: flex-start;

		svg {
			width: 18px;
			height: 18px;
			margin-top: 4px;
		}
	}
}