!function(a){const e=a.az=a.az||{};e.dictionary=Object.assign(e.dictionary||{},{"%0 of %1":"%1-dən %0",Aquamarine:"Akvamarin",Black:"Qara","Block quote":"Sitat bloku",Blue:"Mavi",Bold:"Yarıqalın","Break text":"","Bulleted List":"Markerlənmiş siyahı",Cancel:"İmtina et","Centered image":"Mərkəzə düzləndir","Change image text alternative":"Alternativ mətni redaktə et","Choose heading":"Başlıqı seç",Column:"Sütun","Delete column":"Sütunları sil","Delete row":"Sətirləri sil","Dim grey":"Tünd boz",Downloadable:"Yüklənə bilər","Dropdown toolbar":"Açılan paneli","Edit block":"Redaktə etmək bloku","Edit link":"Linki redaktə et","Editor toolbar":"Redaktorun paneli","Enter image caption":"Şəkil başlığı daxil edin","Full size image":"Tam ölçülü şəkili",Green:"Yaşıl",Grey:"Boz","Header column":"Başlıqlı sütun","Header row":"Başlıqlı sətir",Heading:"Başlıq","Heading 1":"Başlıq 1","Heading 2":"Başlıq 2","Heading 3":"Başlıq 3","Heading 4":"Başlıq 4","Heading 5":"Başlıq 5","Heading 6":"Başlıq 6","Image toolbar":"Şəkil paneli","image widget":"Şəkil vidgetı","In line":"","Insert column left":"Sola sütun əlavə et","Insert column right":"Sağa sütun əlavə et","Insert image":"Şəkili əlavə et","Insert media":"Media əlavə ed","Insert paragraph after block":"","Insert paragraph before block":"","Insert row above":"Aşağıya sətir əlavə et","Insert row below":"Yuxarıya sətir əlavə et","Insert table":"Cədvəli əlavə et",Italic:"Maili","Left aligned image":"Soldan düzləndir","Light blue":"Açıq mavi","Light green":"Açıq yaşıl","Light grey":"Açıq boz",Link:"Əlaqələndir","Link image":"","Link URL":"Linkin URL","Media URL":"Media URL","media widget":"media vidgeti","Merge cell down":"Xanaları aşağı birləşdir","Merge cell left":"Xanaları sola birləşdir","Merge cell right":"Xanaları sağa birləşdir","Merge cell up":"Xanaları yuxarı birləşdir","Merge cells":"Xanaları birləşdir",Next:"Növbəti","Numbered List":"Nömrələnmiş siyahı","Open in a new tab":"Yeni pəncərədə aç","Open link in new tab":"Linki yeni pəncərədə aç",Orange:"Narıncı",Paragraph:"Abzas","Paste the media URL in the input.":"Media URL-ni xanaya əlavə edin",Previous:"Əvvəlki",Purple:"Bənövşəyi",Red:"Qırmızı",Redo:"Təkrar et","Rich Text Editor":"Rich Text Redaktoru","Rich Text Editor, %0":"Rich Text Redaktoru, %0","Right aligned image":"Sağdan düzləndir",Row:"Sətir",Save:"Yadda saxla","Select column":"","Select row":"","Show more items":"Daha çox əşyanı göstərin","Side image":"Yan şəkil","Split cell horizontally":"Xanaları üfüqi böl","Split cell vertically":"Xanaları şaquli böl","Table toolbar":"Cədvəl paneli","Text alternative":"Alternativ mətn","The URL must not be empty.":"URL boş olmamalıdır.","This link has no URL":"Bu linkdə URL yoxdur","This media URL is not supported.":"Bu media URL dəstəklənmir.","Tip: Paste the URL into the content to embed faster.":"Məsləhət: Sürətli qoşma üçün URL-i kontentə əlavə edin","Toggle caption off":"","Toggle caption on":"",Turquoise:"Firuzəyi",Undo:"İmtina et",Unlink:"Linki sil","Upload failed":"Şəkili serverə yüklə","Upload in progress":"Yüklənir",White:"Ağ","Widget toolbar":"Vidgetin paneli","Wrap text":"",Yellow:"Sarı"}),e.getPluralForm=function(a){return 1!=a}}(window.CKEDITOR_TRANSLATIONS||(window.CKEDITOR_TRANSLATIONS={}));