# Generated by Django 4.1.4 on 2024-04-18 09:40

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("xprez", "0025_contentsymlink"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="contentsymlink",
            options={"verbose_name": "Linked module"},
        ),
    ]
