!function(e){const i=e.lt=e.lt||{};i.dictionary=Object.assign(i.dictionary||{},{"%0 of %1":"",Aquamarine:"Aquamarine",Black:"Juoda","Block quote":"Citata",Blue:"Mėlyna",Bold:"Paryškintas","Break text":"","Bulleted List":"Sąrašas",Cancel:"Atšaukti","Centered image":"Vaizdas centre","Change image text alternative":"Pakeisti vaizdo alternatyvųjį tekstą","Choose heading":"Pasirinkite antraštę",Column:"Stulpelis","Delete column":"Ištrinti stulpelį","Delete row":"Ištrinti eilutę","Dim grey":"Pilkšva",Downloadable:"","Dropdown toolbar":"","Edit block":"Redaguoti bloką","Edit link":"Keisti nuorodą","Editor toolbar":"","Enter image caption":"Įveskite vaizdo antraštę","Full size image":"Pilno dydžio vaizdas",Green:"Žalia",Grey:"Pilka","Header column":"Antraštės stulpelis","Header row":"Antraštės eilutė",Heading:"Antraštė","Heading 1":"Antraštė 1","Heading 2":"Antraštė 2","Heading 3":"Antraštė 3","Heading 4":"Antraštė 4","Heading 5":"Antraštė 5","Heading 6":"Antraštė 6","Image toolbar":"","image widget":"vaizdų valdiklis","In line":"","Insert column left":"Įterpti stulpelį kairėje","Insert column right":"Įterpti stulpelį dešinėje","Insert image":"Įterpti vaizdą","Insert media":"Įterpkite media","Insert row above":"Įterpti eilutę aukščiau","Insert row below":"Įterpti eilutę žemiau","Insert table":"Įterpti lentelę",Italic:"Kursyvas","Left aligned image":"Vaizdas kairėje","Light blue":"Šviesiai mėlyna","Light green":"Šviesiai žalia","Light grey":"Šviesiai pilka",Link:"Pridėti nuorodą","Link image":"","Link URL":"Nuorodos URL","Media URL":"Media URL","media widget":"media valdiklis","Merge cell down":"Prijungti langelį apačioje","Merge cell left":"Prijungti langelį kairėje","Merge cell right":"Prijungti langelį dešinėje","Merge cell up":"Prijungti langelį viršuje","Merge cells":"Sujungti langelius",Next:"","Numbered List":"Numeruotas rąrašas","Open in a new tab":"","Open link in new tab":"Atidaryti nuorodą naujame skirtuke",Orange:"Oranžinė",Paragraph:"Paragrafas","Paste the media URL in the input.":"Įklijuokite media URL adresą į įvedimo lauką.",Previous:"",Purple:"Violetinė",Red:"Raudona",Redo:"Pirmyn","Rich Text Editor":"Raiškiojo teksto redaktorius","Rich Text Editor, %0":"Raiškiojo teksto redaktorius, %0","Right aligned image":"Vaizdas dešinėje",Row:"Eilutė",Save:"Išsaugoti","Select column":"","Select row":"","Show more items":"","Side image":"Vaizdas šone","Split cell horizontally":"Padalinti langelį horizontaliai","Split cell vertically":"Padalinti langelį vertikaliai","Table toolbar":"","Text alternative":"Alternatyvusis tekstas","The URL must not be empty.":"URL negali būti tuščias.","This link has no URL":"Ši nuorda neturi URL","This media URL is not supported.":"Šis media URL yra nepalaikomas.","Tip: Paste the URL into the content to embed faster.":"Patarimas: norėdami greičiau įterpti media tiesiog įklijuokite URL į turinį.","Toggle caption off":"","Toggle caption on":"",Turquoise:"Turkio",Undo:"Atgal",Unlink:"Pašalinti nuorodą","Upload failed":"Įkelti nepavyko","Upload in progress":"Įkelima",White:"Balta","Wrap text":"",Yellow:"Geltona"}),i.getPluralForm=function(e){return e%10==1&&(e%100>19||e%100<11)?0:e%10>=2&&e%10<=9&&(e%100>19||e%100<11)?1:e%1!=0?2:3}}(window.CKEDITOR_TRANSLATIONS||(window.CKEDITOR_TRANSLATIONS={}));