{% extends 'xprez/admin/contents/base.html' %}

{% block common_options_wrapper %}{% endblock %}
{% block options_wrapper %}{% endblock %}
{% block btn_copy_content %}{% endblock %}
{% block btn_options %}{% endblock %}

{% block content %}
	<div class="xprez-module__content-info">
		{% if content.symlink %}
			{% include "xprez/admin/icons/page.html" %} <strong>{{ content.symlink.page.polymorph }}</strong>
			<span class="xprez-module__content-info-arr">&#x203A;</span>
			{{content.symlink.polymorph.icon}} <strong>{{ content.symlink.polymorph.verbose_name }}</strong>
		{% else %}
			<div class="xprez-warning">Linked content not found.</div>
		{% endif %}
	</div>
{% endblock %}
