.xprez-add-before {
	position: relative;
	opacity: 1;
	transition: opacity 150ms;

	&:hover {
		opacity: 1;

		&:after,
		.xprez-add__cont:before {
			opacity: 1;
		}
	}

	&:before {
		content: '';
		position: absolute;
		background: transparent;
		height: 16px;
		bottom: 0px;
		left: 0;
		width: 100%;
	}

	&:after {
		content: '';
		position: absolute;
		bottom: 8px;
		left: 0;
		width: 100%;
		height: 1px;
		background: $light-gray;
		opacity: 0.1;
	}

	.xprez-add__cont {
		position: absolute;
		right: 0;

		&:before {
			position: absolute;
			display: block;
			content: '+';
			width: 40px;
			height: 60px;
			right: -40px;
			top: -38px;
			font-weight: bold;
			font-size: 35px;
			color: $b-gray-7;
			display: flex;
			align-items: center;
			justify-content: center;
			opacity: 1;
			cursor: pointer;
		}

		.xprez-submenu {
			margin-top: -2.5rem;
		}
	}

	.xprez-submenu__paste {
		margin-bottom: .15rem !important;
	}
}