!function(e){const t=e.bg=e.bg||{};t.dictionary=Object.assign(t.dictionary||{},{"%0 of %1":"","Block quote":"Цитат",Bold:"Удебелен","Break text":"","Bulleted List":"Водещи символи",Cancel:"Отказ","Centered image":"","Change image text alternative":"","Choose heading":"Избери заглавие",Column:"Колона","Delete column":"Изтриване на колона","Delete row":"Изтриване на ред",Downloadable:"Изтегляне","Edit link":"Редакция на линк","Enter image caption":"","Full size image":"","Header column":"Заглавна колона","Header row":"Заглавен ред",Heading:"Заглавие","Heading 1":"Заглавие 1","Heading 2":"Заглавие 2","Heading 3":"Заглавие 3","Heading 4":"Заглавие 4","Heading 5":"Заглавие 5","Heading 6":"Заглавие 6","Image toolbar":"","image widget":"Компонент за изображение","In line":"","Insert column left":"Вмъкни колона отляво","Insert column right":"Вмъкни колона отдясно","Insert image":"Вмъкни изображение","Insert media":"Вмъкни медия","Insert row above":"Вмъкни ред отгоре","Insert row below":"Вмъкни ред отдолу","Insert table":"Вмъкни таблица",Italic:"Курсив","Left aligned image":"",Link:"Линк","Link image":"","Link URL":"Уеб адрес на линка","Media URL":"Медиен уеб адрес","media widget":"Медиен компонент","Merge cell down":"Обединяване на клетка надолу","Merge cell left":"Обединяване на клетка отляво","Merge cell right":"Обединяване на клетка отдясно","Merge cell up":"Обединяване на клетка отгоре","Merge cells":"Обединяване на клетки","Numbered List":"Номериране","Open in a new tab":"Отваряне в нов раздел","Open link in new tab":"Отваряне на линк в нов раздел",Paragraph:"Параграф","Paste the media URL in the input.":"Постави медииния уеб адрес във входа.",Redo:"Повтори","Right aligned image":"",Row:"Ред",Save:"Запазване","Select column":"","Select row":"","Show more items":"","Side image":"","Split cell horizontally":"Разделяне на клетки хоризонтално","Split cell vertically":"Разделяне на клетки вертикално","Table toolbar":"","Text alternative":"","The URL must not be empty.":"Уеб адресът не трябва да бъде празен.","This link has no URL":"Този линк няма уеб адрес","This media URL is not supported.":"Този медиен уеб адрес не се поддържа.","Tip: Paste the URL into the content to embed faster.":"Полезен съвет: Постави уеб адреса в съдържанието, за да вградите по-бързо.","Toggle caption off":"","Toggle caption on":"",Undo:"Отмени",Unlink:"Премахване на линка","Upload failed":"","Upload in progress":"Качването е в процес","Wrap text":""}),t.getPluralForm=function(e){return 1!=e}}(window.CKEDITOR_TRANSLATIONS||(window.CKEDITOR_TRANSLATIONS={}));