# Generated by Django 4.1.4 on 2024-04-16 16:08

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("xprez", "0024_remove_gridboxes_edge_images_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="ContentSymlink",
            fields=[
                (
                    "content_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="xprez.content",
                    ),
                ),
                (
                    "symlink",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="symlinked_content_set",
                        to="xprez.content",
                    ),
                ),
            ],
            bases=("xprez.content",),
        ),
    ]
